/* test_class.cpp - Demonstrate usage of IAVLaserFeatureProxy class,
 *                  which extends the Player C++ client library
 *                  LaserProxy class to incorporate the IAV circle,
 *                  line, and leg feature extraction routines,
 *                  including high-level "people" tracking (pairs of
 *                  legs) as available in miarn library.
 *
 * Scott Livingston
 * 19 March 2009
 */


#include <iostream>
#include <string>
using namespace std;

#include <cstdlib>
#include <cstring>

#include <libplayerc++/playerc++.h>
using namespace PlayerCc;

#include "IAVLaserFeatureProxy.hpp"


int main( int argc, char *argv[] )
{
	string hostname( "localhost" );
	int port = 6665;

	if (argc > 3 || (argc == 2 && !strcmp( argv[1], "-h" ))) {
		cerr << "Usage: " << argv[0] << " [hostname] [port]" << endl;
		return 1;
	} else if (argc == 2) { // Only hostname specified
		hostname = argv[1];
	} else if (argc == 3) { // Hostname and port number both specified
		hostname = argv[1];
		port = atof( argv[2] );
	}
	
	try {

		PlayerClient robot( hostname.c_str(), port );
		IAVLaserFeatureProxy laserp( &robot, 0 );

		// Main loop
		while (true) {

			robot.Read();

			if (!laserp.IsValid() || !laserp.IsFresh())
				continue;

			laserp.Update();
			//laserp.PrintFeatureCounts();

			cout << "Number of features found:          " << laserp.GetNumFeatures() << endl;
			cout << "Number of 'person' features found: " << laserp.GetNumPersonFeatures() << endl;

			if (laserp.GetNumFeatures() > 0)
				cout << "First feature has position ( " << laserp.GetFeature(0).pos[0] << ", "
					 << laserp.GetFeature(0).pos[1] << " )" << endl;

			if (laserp.GetNumPersonFeatures() > 0)
				cout << "First feature has position ( " << laserp.GetPersonFeature(0).pos[0] << ", "
					 << laserp.GetPersonFeature(0).pos[1] << " )" << endl;
			
		}

	} catch (PlayerError e) {
		cerr << e << endl;
		return -1;
	}
	
	return 0;
}

